import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class WalletCredentialsService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Create wallet credentials
     * Create a new set of wallet credentials.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    createWalletCredential(requestBody: {
        label: string;
        type: 'circle';
        /**
         * 32-byte hex string. Consult https://developers.circle.com/w3s/entity-secret-management to create and register an entity secret.
         */
        entitySecret: string;
        /**
         * Whether this credential should be set as the default for its type. Only one credential can be default per type.
         */
        isDefault?: boolean;
    }): CancelablePromise<{
        result: {
            id: string;
            type: string;
            label: string;
            isDefault: (boolean | null);
            createdAt: string;
            updatedAt: string;
        };
    }>;
    /**
     * Get all wallet credentials
     * Get all wallet credentials with pagination.
     * @param page Specify the page number.
     * @param limit Specify the number of results to return per page.
     * @returns any Default Response
     * @throws ApiError
     */
    getAllWalletCredentials(page?: number, limit?: number): CancelablePromise<{
        result: Array<{
            id: string;
            type: string;
            label: (string | null);
            isDefault: (boolean | null);
            createdAt: string;
            updatedAt: string;
        }>;
    }>;
    /**
     * Get wallet credential
     * Get a wallet credential by ID.
     * @param id The ID of the wallet credential to get.
     * @returns any Default Response
     * @throws ApiError
     */
    getWalletCredential(id: string): CancelablePromise<{
        result: {
            id: string;
            type: string;
            label: (string | null);
            isDefault: (boolean | null);
            createdAt: string;
            updatedAt: string;
            deletedAt: (string | null);
        };
    }>;
    /**
     * Update wallet credential
     * Update a wallet credential's label, default status, and entity secret.
     * @param id The ID of the wallet credential to update.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    updateWalletCredential(id: string, requestBody?: {
        label?: string;
        /**
         * Whether this credential should be set as the default for its type. Only one credential can be default per type.
         */
        isDefault?: boolean;
        /**
         * 32-byte hex string. Consult https://developers.circle.com/w3s/entity-secret-management to create and register an entity secret.
         */
        entitySecret?: string;
    }): CancelablePromise<{
        result: {
            id: string;
            type: string;
            label: (string | null);
            isDefault: (boolean | null);
            createdAt: string;
            updatedAt: string;
        };
    }>;
}
